@@ -18,13 +18,3 @@ NULL
 setClass(Class = "AxisBase", contains = "AmObject",
          representation = representation(guides = "list", "VIRTUAL"))
 
-#' @rdname listProperties-AmObject
-setMethod(f = "listProperties", signature = "AxisBase",
-           definition = function(.Object)
-           { 
-             ls <- callNextMethod()
-             if (length(.Object@guides)) {
-               ls <- rlist::list.append(ls, guides = .Object@guides)
-             } else {}
-             return(ls)
-           })
