@@ -25,5 +25,7 @@ AmCharts.translations[ "export" ][ "lt" ] = {
 	"menu.label.draw.modes": "Režimas ...",
 	"menu.label.draw.modes.pencil": "Tekstą",
 	"menu.label.draw.modes.line": "Linija",
-	"menu.label.draw.modes.arrow": "Rodyklė"
+	"menu.label.draw.modes.arrow": "Rodyklė",
+
+	"label.saved.from": "Išsaugoti nuo: "
 }
\ No newline at end of file
